@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Hardware::Network::NetBSD;
 
-use strict;
+use v5.14.4;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.16.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Array;
