@@ -1,16 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Virtualization::Docker::import;
 
-use 5.010001;
-use strict;
+use v5.14.4;
 use warnings;
 
-our $VERSION = '1.13.3'; # VERSION
+our $VERSION = '1.16.1'; # VERSION
 
 use Data::Dumper;
 use Rex::Logger;
@@ -49,4 +46,3 @@ sub execute {
 }
 
 1;
-
